==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Dialog.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var Dialog = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Dialog, _super);
    function Dialog() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.i = null;
        _this.closing = null;
        _this.closed = null;
        return _this;
    }
    Object.defineProperty(Dialog.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "nativeElement", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.c.n = this.i;
        },
        enumerable: false,
        configurable: true
    });
    Dialog.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Dialog.prototype, "g", {
        get: function () {
            var ret_ = this.d.m("keepOpenOnEscape");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("keepOpenOnEscape", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "e", {
        get: function () {
            var ret_ = this.d.m("closeOnOutsideClick");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("closeOnOutsideClick", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "f", {
        get: function () {
            var ret_ = this.d.m("hideDefaultAction");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("hideDefaultAction", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "h", {
        get: function () {
            var ret_ = this.d.m("open");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("open", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "l", {
        get: function () {
            var ret_ = this.d.m("title");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("title", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "k", {
        get: function () {
            var ret_ = this.d.m("returnValue");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("returnValue", value_);
        },
        enumerable: false,
        configurable: true
    });
    Dialog.prototype.closingChanged = function () {
        var _this = this;
        if (this.closing != null) {
            this.d.q("closing", function (a) { return _this.closing(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.d.t("closing");
        }
    };
    Dialog.prototype.closedChanged = function () {
        var _this = this;
        if (this.closed != null) {
            this.d.q("closed", function (a) { return _this.closed(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.d.t("closed");
        }
    };
    Dialog.prototype.q = function () {
        this.nativeElement.show();
    };
    Dialog.prototype.o = function () {
        this.nativeElement.hide();
    };
    Dialog.prototype.r = function () {
        this.nativeElement.toggle();
    };
    Dialog.$t = markType(Dialog, 'Dialog', BaseElement.$);
    return Dialog;
}(BaseElement));
export { Dialog };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/Dialog.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var Dialog = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Dialog, _super);
    function Dialog() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.i = null;
        _this.closing = null;
        _this.closed = null;
        return _this;
    }
    Object.defineProperty(Dialog.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "nativeElement", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.c.o = this.i;
        },
        enumerable: false,
        configurable: true
    });
    Dialog.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Dialog.prototype, "g", {
        get: function () {
            var ret_ = this.d.n("keepOpenOnEscape");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("keepOpenOnEscape", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "e", {
        get: function () {
            var ret_ = this.d.n("closeOnOutsideClick");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("closeOnOutsideClick", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "f", {
        get: function () {
            var ret_ = this.d.n("hideDefaultAction");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("hideDefaultAction", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "h", {
        get: function () {
            var ret_ = this.d.n("open");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("open", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "l", {
        get: function () {
            var ret_ = this.d.n("title");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("title", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dialog.prototype, "k", {
        get: function () {
            var ret_ = this.d.n("returnValue");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("returnValue", value_);
        },
        enumerable: false,
        configurable: true
    });
    Dialog.prototype.closingChanged = function () {
        var _this = this;
        if (this.closing != null) {
            this.d.r("closing", function (a) { return _this.closing(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.d.u("closing");
        }
    };
    Dialog.prototype.closedChanged = function () {
        var _this = this;
        if (this.closed != null) {
            this.d.r("closed", function (a) { return _this.closed(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.d.u("closed");
        }
    };
    Dialog.prototype.q = function () {
        this.nativeElement.show();
    };
    Dialog.prototype.o = function () {
        this.nativeElement.hide();
    };
    Dialog.prototype.r = function () {
        this.nativeElement.toggle();
    };
    Dialog.$t = markType(Dialog, 'Dialog', BaseElement.$);
    return Dialog;
}(BaseElement));
export { Dialog };
